@@ -1,14 +1,17 @@
+from __future__ import annotations
+
 import contextlib
+import functools
 import os.path
 import shutil
 import tarfile
 from typing import Generator
 from typing import Sequence
-from typing import Tuple
 
 import pre_commit.constants as C
 from pre_commit.envcontext import envcontext
 from pre_commit.envcontext import PatchesT
+from pre_commit.envcontext import UNSET
 from pre_commit.envcontext import Var
 from pre_commit.hook import Hook
 from pre_commit.languages import helpers
@@ -18,32 +21,53 @@ from pre_commit.util import clean_path_on_failure
 from pre_commit.util import resource_bytesio
 
 ENVIRONMENT_DIR = 'rbenv'
-get_default_version = helpers.basic_get_default_version
 healthy = helpers.basic_healthy
 
 
+@functools.lru_cache(maxsize=1)
+def get_default_version() -> str:
+    if all(helpers.exe_exists(exe) for exe in ('ruby', 'gem')):
+        return 'system'
+    else:
+        return C.DEFAULT
+
+
 def get_env_patch(
         venv: str,
         language_version: str,
-) -> PatchesT:  # pragma: win32 no cover
+) -> PatchesT:
     patches: PatchesT = (
         ('GEM_HOME', os.path.join(venv, 'gems')),
-        ('RBENV_ROOT', venv),
+        ('GEM_PATH', UNSET),
         ('BUNDLE_IGNORE_CONFIG', '1'),
-        (
-            'PATH', (
-                os.path.join(venv, 'gems', 'bin'), os.pathsep,
-                os.path.join(venv, 'shims'), os.pathsep,
-                os.path.join(venv, 'bin'), os.pathsep, Var('PATH'),
-            ),
-        ),
     )
-    if language_version != C.DEFAULT:
+    if language_version == 'system':
+        patches += (
+            (
+                'PATH', (
+                    os.path.join(venv, 'gems', 'bin'), os.pathsep,
+                    Var('PATH'),
+                ),
+            ),
+        )
+    else:  # pragma: win32 no cover
+        patches += (
+            ('RBENV_ROOT', venv),
+            (
+                'PATH', (
+                    os.path.join(venv, 'gems', 'bin'), os.pathsep,
+                    os.path.join(venv, 'shims'), os.pathsep,
+                    os.path.join(venv, 'bin'), os.pathsep, Var('PATH'),
+                ),
+            ),
+        )
+    if language_version not in {'system', 'default'}:  # pragma: win32 no cover
         patches += (('RBENV_VERSION', language_version),)
+
     return patches
 
 
-@contextlib.contextmanager  # pragma: win32 no cover
+@contextlib.contextmanager
 def in_env(
         prefix: Prefix,
         language_version: str,
@@ -63,7 +87,7 @@ def _extract_resource(filename: str, dest: str) -> None:
 
 def _install_rbenv(
         prefix: Prefix,
-        version: str = C.DEFAULT,
+        version: str,
 ) -> None:  # pragma: win32 no cover
     directory = helpers.environment_dir(ENVIRONMENT_DIR, version)
 
@@ -90,28 +114,30 @@ def _install_ruby(
 
 def install_environment(
         prefix: Prefix, version: str, additional_dependencies: Sequence[str],
-) -> None:  # pragma: win32 no cover
+) -> None:
     additional_dependencies = tuple(additional_dependencies)
     directory = helpers.environment_dir(ENVIRONMENT_DIR, version)
     with clean_path_on_failure(prefix.path(directory)):
-        # TODO: this currently will fail if there's no version specified and
-        # there's no system ruby installed.  Is this ok?
-        _install_rbenv(prefix, version=version)
+        if version != 'system':  # pragma: win32 no cover
+            _install_rbenv(prefix, version)
+            with in_env(prefix, version):
+                # Need to call this before installing so rbenv's directories
+                # are set up
+                helpers.run_setup_cmd(prefix, ('rbenv', 'init', '-'))
+                if version != C.DEFAULT:
+                    _install_ruby(prefix, version)
+                # Need to call this after installing to set up the shims
+                helpers.run_setup_cmd(prefix, ('rbenv', 'rehash'))
+
         with in_env(prefix, version):
-            # Need to call this before installing so rbenv's directories are
-            # set up
-            helpers.run_setup_cmd(prefix, ('rbenv', 'init', '-'))
-            if version != C.DEFAULT:
-                _install_ruby(prefix, version)
-            # Need to call this after installing to set up the shims
-            helpers.run_setup_cmd(prefix, ('rbenv', 'rehash'))
             helpers.run_setup_cmd(
                 prefix, ('gem', 'build', *prefix.star('.gemspec')),
             )
             helpers.run_setup_cmd(
                 prefix,
                 (
-                    'gem', 'install', '--no-document',
+                    'gem', 'install',
+                    '--no-document', '--no-format-executable',
                     *prefix.star('.gem'), *additional_dependencies,
                 ),
             )
@@ -121,6 +147,6 @@ def run_hook(
         hook: Hook,
         file_args: Sequence[str],
         color: bool,
-) -> Tuple[int, bytes]:  # pragma: win32 no cover
+) -> tuple[int, bytes]:
     with in_env(hook.prefix, hook.language_version):
         return helpers.run_xargs(hook, hook.cmd, file_args, color=color)
